@@ -239,4 +239,13 @@ void field_init_fast_fp(field_ptr f, mpz_t prime);
 static inline void field_init_fp(field_ptr f, mpz_t prime) {
     field_init_naive_fp(f, prime);
 }
+
+//The following only work for groups of points on elliptic curves:
+int element_to_bytes_x_only(unsigned char *data, element_ptr e);
+int element_from_bytes_x_only(element_ptr e, unsigned char *data);
+int element_length_in_bytes_x_only(element_ptr e);
+int element_to_bytes_compressed(unsigned char *data, element_ptr e);
+int element_from_bytes_compressed(element_ptr e, unsigned char *data);
+int element_length_in_bytes_compressed(element_ptr e);
+
 #endif //FIELD_H
