@@ -15,6 +15,35 @@ static inline char *strclone(char *src)
     return dst;
 }
 
+int generic_is_almost_coddh(element_ptr a, element_ptr b,
+	element_ptr c, element_ptr d, pairing_t pairing)
+{
+    int res = 0;
+    element_t t0, t1;
+
+    element_init(t0, pairing->GT);
+    element_init(t1, pairing->GT);
+    bilinear_map(t0, a, d, pairing);
+    bilinear_map(t1, b, c, pairing);
+    if (!element_cmp(t0, t1)) {
+	res = 1;
+    } else {
+	element_mul(t0, t0, t1);
+	if (element_is1(t0)) res = 1;
+    }
+    element_clear(t0);
+    element_clear(t1);
+    return res;
+}
+
+static void phi_warning(element_ptr out, element_ptr in, pairing_ptr pairing)
+{
+    (void) out;
+    (void) in;
+    (void) pairing;
+    printf("Phi() not implemented for this pairing type yet!\n");
+}
+
 void pairing_init_inp_str(pairing_t pairing, FILE *stream)
 {
     char *s;
@@ -32,6 +61,8 @@ void pairing_init_inp_str(pairing_t pairing, FILE *stream)
     }
     s = pairing->id = strclone(tok->s);
 
+    pairing->is_almost_coddh = generic_is_almost_coddh;
+    pairing->phi = phi_warning;
     if (!strcmp(s, "a")) {
 	a_param_t ap;
 
@@ -63,24 +94,3 @@ void pairing_init_inp_str(pairing_t pairing, FILE *stream)
     }
     token_clear(tok);
 }
-
-int generic_is_almost_coddh(element_ptr a, element_ptr b,
-	element_ptr c, element_ptr d, pairing_t pairing)
-{
-    int res = 0;
-    element_t t0, t1;
-
-    element_init(t0, pairing->GT);
-    element_init(t1, pairing->GT);
-    bilinear_map(t0, a, d, pairing);
-    bilinear_map(t1, b, c, pairing);
-    if (!element_cmp(t0, t1)) {
-	res = 1;
-    } else {
-	element_mul(t0, t0, t1);
-	if (element_is1(t0)) res = 1;
-    }
-    element_clear(t0);
-    element_clear(t1);
-    return res;
-}
